#!/bin/bash
CERTFILES=("/usr/share/beid/certs/beid-cert-belgiumrca.der" "/usr/share/beid/certs/beid-cert-belgiumrca2.der")
EXPECTFILE="/usr/lib64/eidconfig-belgium/changepin.exp"
PKCS11MOD="/usr/lib64/pkcs11/libbeidpkcs11.so"
PKCS11TOOL="beid-pkcs11-tool"
PKCS11NAME="Belgium Identity Card PKCS#11"

FFBASE="$HOME""/.mozilla/firefox"
TBIRDBASE="$HOME""/.thunderbird"
# If there's an OpenOffice 3.0 profile, we use that -- even if there's 
# also a 2.0 profile. In that case, the environment variable points to
# the 3.0 profile.
# If there is no 3.0 profile but there's an OpenOffice 2.0 profile, we
# use that one.
OOBASE="$HOME""/.ooo3/user"
if [ ! -d ${OOBASE} ] && [ -d "$HOME""/.ooo-2.0/user" ] ; then
	OOBASE="$HOME""/.ooo-2.0/user"
fi
EVOBASE="$HOME""/.evolution"

OO="false"
GOON="true"
PIN=""
CALL=""
ARG=""
PROFILE=""
OCSP=""
OCSP_LINE=""
CRL=""
CRL_LINE=""

########################################################

function enable_secmoddb_dir ()
{
if [ -f ${1}/secmod.db ] ; then
	add_beleid_to_secmod $1
else
	create_new_databases $1
	add_beleid_to_secmod $1
fi

if [ $OO = "true" ] ; then
	if [ -d "$HOME""/.ooo3/user" ] ; then
		# If an OOo.org 2.0 profile is already enabled, and then we enable a 3.0 profile,
		# the environment variable will still point to the 2.0 profile, so we first remove that.
		if grep 'export MOZILLA_CERTIFICATE_FOLDER=~/.ooo-2.0/user' ~/.profile 2>/dev/null 1>&2; then
			grep -v 'export MOZILLA_CERTIFICATE_FOLDER=~/.ooo-2.0/user' ~/.profile > /tmp/.profile.eID
			mv /tmp/.profile.eID ~/.profile
		fi
		if grep 'export MOZILLA_CERTIFICATE_FOLDER=~/.ooo-2.0/user' ~/.bash_profile 2>/dev/null 1>&2; then
			grep -v 'export MOZILLA_CERTIFICATE_FOLDER=~/.ooo-2.0/user' ~/.bash_profile> /tmp/.bash_profile.eID
			mv /tmp/.bash_profile.eID ~/.bash_profile
		fi

		if [ -f ~/.bash_profile ] ; then
			echo "export MOZILLA_CERTIFICATE_FOLDER=~/.ooo3/user" >> ~/.bash_profile
			echo "export MOZILLA_CERTIFICATE_FOLDER=~/.ooo3/user" >> ~/.profile
		else
			echo "export MOZILLA_CERTIFICATE_FOLDER=~/.ooo3/user" >> ~/.profile
		fi
	else
		# If an OOo.org 3.0 profile is already enabled, and then we enable a 2.0 profile (unlikely),
		# the environment variable will still point to the 3.0 profile, so we first remove that.
		if grep 'export MOZILLA_CERTIFICATE_FOLDER=~/.ooo3/user' ~/.profile 2>/dev/null 1>&2; then
			grep -v 'export MOZILLA_CERTIFICATE_FOLDER=~/.ooo3/user' ~/.profile > /tmp/.profile.eID
			mv /tmp/.profile.eID ~/.profile
		fi
		if grep 'export MOZILLA_CERTIFICATE_FOLDER=~/.ooo3/user' ~/.bash_profile 2>/dev/null 1>&2; then
			grep -v 'export MOZILLA_CERTIFICATE_FOLDER=~/.ooo3/user' ~/.bash_profile> /tmp/.bash_profile.eID
			mv /tmp/.bash_profile.eID ~/.bash_profile
		fi

		if [ -f ~/.bash_profile ] ; then
			echo "export MOZILLA_CERTIFICATE_FOLDER=~/.ooo-2.0/user" >> ~/.bash_profile
			echo "export MOZILLA_CERTIFICATE_FOLDER=~/.ooo-2.0/user" >> ~/.profile
		else
			echo "export MOZILLA_CERTIFICATE_FOLDER=~/.ooo-2.0/user" >> ~/.profile
		fi
	fi
fi
}

function create_new_databases ()
{
modutil -force -create -dbdir $1
}

function add_beleid_to_secmod ()
{
if modutil -force -add "$PKCS11NAME" -libfile $PKCS11MOD -dbdir $1; then
	:
else
	modutil -force -delete "$PKCS11NAME" -dbdir $1
	if modutil -force -add "$PKCS11NAME" -libfile $PKCS11MOD -dbdir $1; then
		:
	else
		exit 255
	fi
fi

local INDEX=0
while [ $INDEX -lt ${#CERTFILES[*]} ] ; do
	if [ -f "${CERTFILES[$INDEX]}" ] ; then
		if [ $INDEX -eq "0" ] ; then
			NAME_INDEX=""
		else
			NAME_INDEX=" `expr $INDEX + 1`"
		fi

		if certutil -A -n "Belgium Root Self Signed$NAME_INDEX" -t "CT,CT,CT" -d $1 -i "${CERTFILES[$INDEX]}" ; then
			:
		else
			if certutil -A -n "Belgium Root Self Signed$NAME_INDEX" -t "CT,CT,CT" -d $1 -i "${CERTFILES[$INDEX]}" ; then
				:
			else
				disable_secmoddb_dir $1
				exit 255
			fi
		fi
	fi
	INDEX=`expr $INDEX + 1`
done
}



#######################################################

function remove_beleid_from_secmod ()
{
modutil -list -dbdir $1 2>/dev/null > /tmp/modlist.tmp
PKCS11MOD_BASENAME=`basename $PKCS11MOD`
LINENUMBER=`cat /tmp/modlist.tmp | grep -n $PKCS11MOD_BASENAME | cut -f 1 -d :`
LINENUMBER=$(( LINENUMBER - 1 ))
DISCOVERED_PKCS11MOD_NAME=`cat /tmp/modlist.tmp | head -n ${LINENUMBER} | tail -n 1 | cut -d . -f 2- | cut -d ' ' -f 2-`
rm /tmp/modlist.tmp
if [ -n "$DISCOVERED_PKCS11MOD_NAME" ] ; then
	modutil -force -delete "$DISCOVERED_PKCS11MOD_NAME" -dbdir $1
fi
}

function disable_secmoddb_dir ()
{
remove_beleid_from_secmod $1
if [ $OO = "true" ] ; then
	if grep 'export MOZILLA_CERTIFICATE_FOLDER=~/.ooo3/user' ~/.profile 2>/dev/null 1>&2; then
		grep -v 'export MOZILLA_CERTIFICATE_FOLDER=~/.ooo3/user' ~/.profile > /tmp/.profile.eID
		mv /tmp/.profile.eID ~/.profile
	fi
	if grep 'export MOZILLA_CERTIFICATE_FOLDER=~/.ooo3/user' ~/.bash_profile 2>/dev/null 1>&2; then
		grep -v 'export MOZILLA_CERTIFICATE_FOLDER=~/.ooo3/user' ~/.bash_profile> /tmp/.bash_profile.eID
		mv /tmp/.bash_profile.eID ~/.bash_profile
	fi
	if grep 'export MOZILLA_CERTIFICATE_FOLDER=~/.ooo-2.0/user' ~/.profile 2>/dev/null 1>&2; then
		grep -v 'export MOZILLA_CERTIFICATE_FOLDER=~/.ooo-2.0/user' ~/.profile > /tmp/.profile.eID
		mv /tmp/.profile.eID ~/.profile
	fi
	if grep 'export MOZILLA_CERTIFICATE_FOLDER=~/.ooo-2.0/user' ~/.bash_profile 2>/dev/null 1>&2; then
		grep -v 'export MOZILLA_CERTIFICATE_FOLDER=~/.ooo-2.0/user' ~/.bash_profile> /tmp/.bash_profile.eID
		mv /tmp/.bash_profile.eID ~/.bash_profile
	fi
fi
}

#######################################################
function check_secmoddb_dir ()
{
if [ -f "${1}/secmod.db" ] ; then
	# When an eID card is inserted, "-rawlist" is much
	# faster than "-list", but "-rawlist" doesn't
	# work when the directory name contains spaces.
	SPACES="x"`echo $1 | grep " "`
	if [ "$SPACES" = "x" ] ; then
		PKCS11MOD_BASENAME=`basename $PKCS11MOD`
		if modutil -rawlist -dbdir "$1" 2>/dev/null | grep "library=" | sed -e "s/.*\(library=\)\(\S*\).*/\2/" | grep $PKCS11MOD_BASENAME >/dev/null 2>&1; then
			return 0
		else
			return 1
		fi
	else
		if modutil -list -dbdir "$1" 2>/dev/null | grep "library name:" | grep $PKCS11MOD >/dev/null 2>&1; then
			return 0
		else
			return 1
		fi
	fi
else
	return 1
fi
}

#######################################################
 
function display_gui ()
{
local INDEX=0
while [ $INDEX -lt ${#application_array[*]} ] ; do
	if [ `echo "${application_array[$INDEX]}" | cut -d ' ' -f 1` = "Firefox" ] ; then
		echo -e ${application_array[$INDEX]} ${application_status_array[$INDEX]}
	elif [ `echo "${application_array[$INDEX]}" | cut -d ' ' -f 1` = "Thunderbird" ] ; then
		echo -e ${application_array[$INDEX]} ${application_status_array[$INDEX]}
	else
		echo -e ${application_array[$INDEX]} ${application_status_array[$INDEX]}
	fi
	INDEX=`expr $INDEX + 1`
done
}

#######################################################

function current_status ()
{

local INDEX=0
if [ -f "$FFBASE/profiles.ini" ] ; then
	cfg.parser ${FFBASE}/profiles.ini
	for PROF in `grep "\[Profile.*\]" ${FFBASE}/profiles.ini | cut -d '=' -f 2 | tr -d "[]"`
	do
		Name=
		Path=
		IsRelative=
		cfg.section.${PROF}
		PROFNAME=${Name[*]}
		PROFDIR=${Path[*]}
		ISRELATIVEPATH=${IsRelative}
		if [ "x"${ISRELATIVEPATH} = "x""0" ] ; then
			APPBASE=${PROFDIR}
		else
			APPBASE=${FFBASE}/${PROFDIR}
		fi
		if [ -d ${APPBASE} ] ; then
			application_array[$INDEX]="Firefox $PROFNAME"
			application_home_array[$INDEX]="${APPBASE}"
			if check_secmoddb_dir "${APPBASE}" ; then
				application_status_array[$INDEX]="true"
			else
				application_status_array[$INDEX]="false"
			fi
			INDEX=`expr $INDEX + 1`
		fi
	done
else
	PROFNAME="default"
        application_array[$INDEX]="Firefox $PROFNAME"
        application_home_array[$INDEX]="${FFBASE}/${PROFNAME}"
        application_status_array[$INDEX]="absent"
        INDEX=`expr $INDEX + 1`
fi

if [ -f "$TBIRDBASE/profiles.ini" ] ; then
	cfg.parser ${TBIRDBASE}/profiles.ini
	for PROF in `grep "\[Profile.*\]" ${TBIRDBASE}/profiles.ini | cut -d '=' -f 2 | tr -d "[]"`
	do
		Path=
		IsRelative=
		Name=
		cfg.section.${PROF}
		PROFNAME=${Name[*]}
		PROFDIR=${Path[*]}
		ISRELATIVEPATH=${IsRelative}
		if [ "x"${ISRELATIVEPATH} = "x""0" ] ; then
			APPBASE=${PROFDIR}
		else
			APPBASE=${TBIRDBASE}/${PROFDIR}
		fi
		if [ -d ${APPBASE} ] ; then
			application_array[$INDEX]="Thunderbird $PROFNAME"
			application_home_array[$INDEX]="${APPBASE}"
			if check_secmoddb_dir "${APPBASE}" ; then
				application_status_array[$INDEX]="true"
			else
				application_status_array[$INDEX]="false"
			fi
			INDEX=`expr $INDEX + 1`
		fi
	done
else
	PROFNAME="default"
        application_array[$INDEX]="Thunderbird $PROFNAME"
        application_home_array[$INDEX]="${TBIRDBASE}/${PROFNAME}"
        application_status_array[$INDEX]="absent"
        INDEX=`expr $INDEX + 1`
fi

if [ -d "$OOBASE" ] ; then
	application_array[$INDEX]="OpenOffice"
	application_home_array[$INDEX]="$OOBASE"
	if check_secmoddb_dir "${OOBASE}" ; then
		application_status_array[$INDEX]="true"
	else
		application_status_array[$INDEX]="false"
	fi
	INDEX=`expr $INDEX + 1`
else
        application_array[$INDEX]="OpenOffice"
        application_home_array[$INDEX]="$OOBASE"
        application_status_array[$INDEX]="absent"
        INDEX=`expr $INDEX + 1`
fi

if [ -d "$EVOBASE" ] ; then
	application_array[$INDEX]="Evolution"
	application_home_array[$INDEX]="$EVOBASE"
	if check_secmoddb_dir "$EVOBASE" ; then
		application_status_array[$INDEX]="true"
	else
		application_status_array[$INDEX]="false"
	fi
	INDEX=`expr $INDEX + 1`
else
	application_array[$INDEX]="Evolution"
        application_home_array[$INDEX]="$EVOBASE"
        application_status_array[$INDEX]="absent"
	INDEX=`expr $INDEX + 1`

fi
}	

#######################################################

function changerevocheck () {
	if [ -f ~/.beidgui_ui.conf ] ; then
		if [ "$1" = "ocsp" ] ; then
			if sed -e "s/OCSP=.*/OCSP=$2/" < ~/.beidgui_ui.conf > /tmp/.beidgui_ui.conf.tmp ; then
				mv /tmp/.beidgui_ui.conf.tmp ~/.beidgui_ui.conf
			fi
		else
			if sed -e "s/CRL=.*/CRL=$2/" < ~/.beidgui_ui.conf > /tmp/.beidgui_ui.conf.tmp ; then
				mv /tmp/.beidgui_ui.conf.tmp ~/.beidgui_ui.conf
			fi
		fi
	fi
}

#######################################################

function usage () {
        exec 1>&2
        echo "Usage: $0 [ -c [0|1|2] | -o [0|1|2] | -r | -s | -p PIN -n (new)PIN | -e [ Evolution | OpenOffice | Firefox -f Profile | Thunderbird -f Profile ] | -d [ Evolution | OpenOffice | Firefox -f Profile | Thunderbird -f Profile ] ]"
        exit 255
}


#######################################################
# Source: http://ajdiaz.wordpress.com/2008/02/09/bash-ini-parser/

function cfg.parser () {
	IFS=$'\n' && ini=( $(<$1) ) # convert to line-array
	ini=( ${ini[*]//;*/} )                   # remove comments
	ini=( ${ini[*]/#[/\}$'\n'cfg.section.} ) # set section prefix
	ini=( ${ini[*]/%]/ \(} )                 # convert text2function (1)
	ini=( ${ini[*]/=/=\( } )                 # convert item to array
	ini=( ${ini[*]/%/ \)} )                  # close array parenthesis
	ini=( ${ini[*]/%\( \)/\(\) \{} )         # convert text2function (2)
	ini=( ${ini[*]/%\} \)/\}} )              # remove extra parenthesis
	ini[0]=''                                # remove first element
	ini[${#ini[*]} + 1]='}'                  # add the last brace
	eval "$(echo "${ini[*]}")"               # eval the result
}


#######################################################


if [ -f ~/.beidgui_ui.conf ] ; then
	:
else
	cat > ~/.beidgui_ui.conf <<EOF
SCReader=
Language=3
OCSP=0
CRL=0
Fonts=
Fontsize=10
EOF
fi

while getopts p:n:c:o:re:d:sf: OPT 
do
	case "$OPT" in
	c)
		if [ -z "$ARG" ] ; then
               		ARG="$OPTARG"
		fi
		if [ -z "$CALL" ] ; then
                       	CALL="crl"
		fi
                ;;
        o)
		if [ -z "$ARG" ] ; then
                       	ARG="$OPTARG"
		fi
		if [ -z "$CALL" ] ; then
                       	CALL="ocsp"
		fi
                ;;
        r)
		if [ -z "$ARG" ] ; then
                       	ARG="$OPTARG"
		fi
		if [ -z "$CALL" ] ; then
                       	CALL="showrevoke"
		fi
                ;;
        p)
                PIN="$OPTARG"
                ;;
        n)
		if [ -z "$ARG" ] ; then
                       	ARG="$OPTARG"
		fi
		if [ -z "$CALL" ] ; then
                       	CALL="changepin"
		fi
                ;;
        e)
		if [ -z "$ARG" ] ; then
                       	ARG="$OPTARG"
		fi
		if [ -z "$CALL" ] ; then
                       	CALL="enable"
		fi
                ;;
        d)
		if [ -z "$ARG" ] ; then
                       	ARG="$OPTARG"
		fi
		if [ -z "$CALL" ] ; then
                       	CALL="disable"
		fi
                ;;
        s)
		if [ -z "$ARG" ] ; then
                       	ARG="$OPTARG"
		fi
		if [ -z "$CALL" ] ; then
                       	CALL="showapps"
		fi
                ;;
	f)
		PROFILE="$OPTARG"
		;;
        \?)
                usage
                ;;
	esac
done

case "$CALL" in
ocsp)
	case $ARG in
	0)
		changerevocheck ocsp 0
		;;
	1)
		changerevocheck ocsp 1
		;;
	2)
		changerevocheck ocsp 2
		;;
	*)
		usage
		;;
	esac
	;;
	
crl)
	case $ARG in
	0)
		changerevocheck crl 0
		;;
	1)
		changerevocheck crl 1
		;;
	2)
		changerevocheck crl 2
		;;
	*)
		usage
		;;
	esac
	;;

showrevoke)
	if [ -f ~/.beidgui_ui.conf ] ; then
		if OCSP_LINE=`grep -i 'ocsp=.' ~/.beidgui_ui.conf` ; then
			OCSP=`echo $OCSP_LINE | cut -d '=' -f 2`
			echo "ocsp=$OCSP"
		fi
		if CRL_LINE=`grep -i 'crl=.' ~/.beidgui_ui.conf` ; then
			CRL=`echo $CRL_LINE | cut -d '=' -f 2`
			echo "crl=$CRL"
		fi
	else
		echo "ocsp=0"
		echo "crl=0"
	fi
	;;

changepin)
	if [ -z "$PIN" ] ; then
                usage
        fi

	#if [ -z $2 -o -z $3 ] ; then
	#		exit 255
	#	fi
	if expect -f "$EXPECTFILE" "$PKCS11TOOL" "$PKCS11MOD" "$PIN" "$ARG" ; then
		exit 0
	else
		exit 255
	fi
	;;
showapps)
	current_status
	display_gui
	;;
enable)
	case $ARG in
	Firefox)
		if [ ! -f ${FFBASE}/profiles.ini ] ; then
			exit 255
		fi
		cfg.parser ${FFBASE}/profiles.ini
		if [ "$PROFILE" ] ; then
			for PROF in `grep "\[Profile.*\]" ${FFBASE}/profiles.ini | cut -d '=' -f 2 | tr -d "[]"`
			do
				Name=
				Path=
				IsRelative=
				cfg.section.${PROF}
				PROFNAME=${Name[*]}
				PROFDIR=${Path[*]}
				ISRELATIVEPATH=${IsRelative}
				if [ ${PROFNAME} = ${PROFILE} ] ; then
					if [ "x"${ISRELATIVEPATH} = "x""0" ] ; then
						APPBASE=${PROFDIR}
					else
						APPBASE=${FFBASE}/${PROFDIR}
					fi
					if [ -d ${APPBASE} ] ; then
						if check_secmoddb_dir $APPBASE ; then
							:
						else
							enable_secmoddb_dir $APPBASE 
						fi	
					else
						exit 255
					fi
				fi
			done
		else
			for PROF in `grep "\[Profile.*\]" ${FFBASE}/profiles.ini | cut -d '=' -f 2 | tr -d "[]"`
			do
				Path=
				IsRelative=
				cfg.section.${PROF}
				PROFDIR=${Path[*]}
				ISRELATIVEPATH=${IsRelative}
				if [ "x"${ISRELATIVEPATH} = "x""0" ] ; then
					APPBASE=${PROFDIR}
				else
					APPBASE=${FFBASE}/${PROFDIR}
				fi
				if [ -d ${APPBASE} ] ; then
					if check_secmoddb_dir $APPBASE ; then
						:
					else
						enable_secmoddb_dir $APPBASE
					fi	
				fi
			done
		fi
		;;	
	Thunderbird)
		if [ ! -f ${TBIRDBASE}/profiles.ini ] ; then
			exit 255
		fi
		cfg.parser ${TBIRDBASE}/profiles.ini
		if [ "$PROFILE" ] ; then
			for PROF in `grep "\[Profile.*\]" ${TBIRDBASE}/profiles.ini | cut -d '=' -f 2 | tr -d "[]"`
			do
				Name=
				Path=
				IsRelative=
				cfg.section.${PROF}
				PROFNAME=${Name[*]}
				PROFDIR=${Path[*]}
				ISRELATIVEPATH=${IsRelative}
				if [ ${PROFNAME} = ${PROFILE} ] ; then
					if [ "x"${ISRELATIVEPATH} = "x""0" ] ; then
						APPBASE=${PROFDIR}
					else
						APPBASE=${TBIRDBASE}/${PROFDIR}
					fi
					if [ -d ${APPBASE} ] ; then
						if check_secmoddb_dir $APPBASE ; then
							:
						else
							enable_secmoddb_dir $APPBASE 
						fi	
					else
						exit 255
					fi
				fi
			done
		else
			for PROF in `grep "\[Profile.*\]" ${TBIRDBASE}/profiles.ini | cut -d '=' -f 2 | tr -d "[]"`
			do
				Path=
				IsRelative=
				cfg.section.${PROF}
				PROFDIR=${Path[*]}
				ISRELATIVEPATH=${IsRelative}
				if [ "x"${ISRELATIVEPATH} = "x""0" ] ; then
					APPBASE=${PROFDIR}
				else
					APPBASE=${TBIRDBASE}/${PROFDIR}
				fi
				if [ -d ${APPBASE} ] ; then
					if check_secmoddb_dir $APPBASE ; then
						:
					else
						enable_secmoddb_dir $APPBASE
					fi	
				fi
			done
		fi
		;;	
	OpenOffice)
		OO=true
		if [ -d ${OOBASE} ] ; then
       	         	APPBASE=${OOBASE}
       	         	if check_secmoddb_dir $APPBASE ; then
				:
       	        	else
       	                	enable_secmoddb_dir $APPBASE 
       	         	fi
	
       	 	else
       	        	exit 255
       	 	fi
		;;
	Evolution)
		if [ -d ${EVOBASE} ] ; then
       	        	APPBASE=${EVOBASE}
       	        	if check_secmoddb_dir $APPBASE ; then
				:
       	         	else
       	                	enable_secmoddb_dir $APPBASE 
       	        	fi
	
       	 	else
       	        	exit 255
       	 	fi
		;;
	*)
		usage
		;;
	esac
	;;
disable)
	case $ARG in
	Firefox)
		if [ ! -f ${FFBASE}/profiles.ini ] ; then
			exit 255
		fi
		cfg.parser ${FFBASE}/profiles.ini
		if [ "$PROFILE" ] ; then
			for PROF in `grep "\[Profile.*\]" ${FFBASE}/profiles.ini | cut -d '=' -f 2 | tr -d "[]"`
			do
				Name=
				Path=
				IsRelative=
				cfg.section.${PROF}
				PROFNAME=${Name[*]}
				PROFDIR=${Path[*]}
				ISRELATIVEPATH=${IsRelative}
				if [ ${PROFNAME} = ${PROFILE} ] ; then
					if [ "x"${ISRELATIVEPATH} = "x""0" ] ; then
						APPBASE=${PROFDIR}
					else
						APPBASE=${FFBASE}/${PROFDIR}
					fi
					if [ -d ${APPBASE} ] ; then
						if check_secmoddb_dir $APPBASE ; then
							disable_secmoddb_dir $APPBASE 
						else
							:
						fi	
					else
						exit 255
					fi
				fi
			done
		else
			for PROF in `grep "\[Profile.*\]" ${FFBASE}/profiles.ini | cut -d '=' -f 2 | tr -d "[]"`
			do
				Path=
				IsRelative=
				cfg.section.${PROF}
				PROFDIR=${Path[*]}
				ISRELATIVEPATH=${IsRelative}
				if [ "x"${ISRELATIVEPATH} = "x""0" ] ; then
					APPBASE=${PROFDIR}
				else
					APPBASE=${FFBASE}/${PROFDIR}
				fi
				if [ -d ${APPBASE} ] ; then
					if check_secmoddb_dir $APPBASE ; then
						disable_secmoddb_dir $APPBASE
					else
						:
					fi	
				fi
			done
		fi
		;;
	Thunderbird)
		if [ ! -f ${TBIRDBASE}/profiles.ini ] ; then
			exit 255
		fi
		cfg.parser ${TBIRDBASE}/profiles.ini
		if [ "$PROFILE" ] ; then
			for PROF in `grep "\[Profile.*\]" ${TBIRDBASE}/profiles.ini | cut -d '=' -f 2 | tr -d "[]"`
			do
				Name=
				Path=
				IsRelative=
				cfg.section.${PROF}
				PROFNAME=${Name[*]}
				PROFDIR=${Path[*]}
				ISRELATIVEPATH=${IsRelative}
				if [ ${PROFNAME} = ${PROFILE} ] ; then
					if [ "x"${ISRELATIVEPATH} = "x""0" ] ; then
						APPBASE=${PROFDIR}
					else
						APPBASE=${TBIRDBASE}/${PROFDIR}
					fi
					if [ -d ${APPBASE} ] ; then
						if check_secmoddb_dir $APPBASE ; then
							disable_secmoddb_dir $APPBASE 
						else
							:
						fi	
					else
						exit 255
					fi
				fi
			done
		else
			for PROF in `grep "\[Profile.*\]" ${TBIRDBASE}/profiles.ini | cut -d '=' -f 2 | tr -d "[]"`
			do
				Path=
				IsRelative=
				cfg.section.${PROF}
				PROFDIR=${Path[*]}
				ISRELATIVEPATH=${IsRelative}
				if [ "x"${ISRELATIVEPATH} = "x""0" ] ; then
					APPBASE=${PROFDIR}
				else
					APPBASE=${TBIRDBASE}/${PROFDIR}
				fi
				if [ -d ${APPBASE} ] ; then
					if check_secmoddb_dir $APPBASE ; then
						disable_secmoddb_dir $APPBASE
					else
						:
					fi	
				fi
			done
		fi
		;;
	OpenOffice)
		OO=true
		if [ -d ${OOBASE} ] ; then
                	APPBASE=${OOBASE}
                	if check_secmoddb_dir $APPBASE ; then
                       		disable_secmoddb_dir $APPBASE
                	else
				:
                	fi

        	else
                	exit 255
        	fi
		;;
	Evolution)
		if [ -d ${EVOBASE} ] ; then
                	APPBASE=${EVOBASE}
                	if check_secmoddb_dir $APPBASE ; then
                        	disable_secmoddb_dir $APPBASE
                	else
				:
                	fi

        	else
                	exit 255
        	fi
		;;
	*)
		usage	
		;;
	esac
	;;
*)
	exit 255
	;;
esac
